@@ -19,7 +19,7 @@ Usage::
     describe_environment_memberships_paginator: DescribeEnvironmentMembershipsPaginator = client.get_paginator("describe_environment_memberships")
     list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
 """
-from mypy_boto3_cloud9.client import Cloud9Client, Cloud9Client as Client
+from mypy_boto3_cloud9.client import Cloud9Client as Client, Cloud9Client
 from mypy_boto3_cloud9.paginator import (
     DescribeEnvironmentMembershipsPaginator,
     ListEnvironmentsPaginator,
